@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.api_api import ApiApi
+#   from .api.jobs_api import JobsApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,4 +14,7 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
-from satnogsnetworkapiclient.api.api_api import ApiApi
+from satnogsnetworkapiclient.api.jobs_api import JobsApi
+from satnogsnetworkapiclient.api.observations_api import ObservationsApi
+from satnogsnetworkapiclient.api.stations_api import StationsApi
+from satnogsnetworkapiclient.api.transmitters_api import TransmittersApi
